@@ -10,7 +10,7 @@
 
 #define PODOFO_VERSION_MAJOR 0
 #define PODOFO_VERSION_MINOR 9
-#define PODOFO_VERSION_PATCH 5
+#define PODOFO_VERSION_PATCH 6
 
 /* PoDoFo configuration options */
 #define PODOFO_MULTI_THREAD
@@ -38,10 +38,10 @@
 
 /* Sizes of int64 and long, to pick proper printf format */
 #define SZ_INT64 8
-#define SZ_LONG 8
+#define SZ_LONG 4
 
 /* Endianness */
-#define TEST_BIG
+/* #undef TEST_BIG */
 
 /* Features */
 /* #undef PODOFO_NO_FONTMANAGER */
@@ -53,7 +53,9 @@
 #define PODOFO_HAVE_FONTCONFIG
 /* #undef PODOFO_HAVE_LUA */
 /* #undef PODOFO_HAVE_BOOST */
-#define PODOFO_HAVE_CPPUNIT
+/* #undef PODOFO_HAVE_CPPUNIT */
 #define PODOFO_HAVE_OPENSSL
 #define PODOFO_HAVE_OPENSSL_1_1
+/* #undef PODOFO_HAVE_OPENSSL_NO_RC4 */
 #define PODOFO_HAVE_LIBIDN
+#define PODOFO_HAVE_UNISTRING_LIB
